@@ -14,7 +14,7 @@ class base:
             "params": p
 
         }
-        # print(data)
+        print(data)
 
         data = json.dumps(data)
         r = requests.post(url=self.url, data=data)
@@ -29,6 +29,15 @@ class Send(base):
     def __init__(self, u, t):
         base.__init__(self, u, t)
 
+    def div(self, f, p):
+        """
+        do it self
+        :param f:
+        :param p:
+        :return:
+        """
+        return base.post_data(self, f, p)
+
     def get_friend_list(self, qq_number):
         f = "Api_GetFriendList"
         p = {
@@ -75,7 +84,7 @@ class Send(base):
         }
         return base.post_data(self, f, p)
 
-    def send_other_msg(self, qq_number, other_qq_number, content,msg_type):
+    def send_other_msg(self, qq_number, other_qq_number, content, msg_type):
         f = "Api_SendMsg"
         p = {
             "c1": qq_number,
@@ -88,6 +97,22 @@ class Send(base):
         return base.post_data(self, f, p)
 
 
+class tool:
+
+    @staticmethod
+    def python_to_json(content):
+
+        return json.dumps(content)
+
+    @staticmethod
+    def json_to_python(content):
+        return json.loads(content)
+
+
 # bot = Send("http://localhost:8889/MyQQHTTPAPI", "666")
-# send = bot.send_msg("3414744631", "2696047693", "Hello world")
-# print(send)
+#
+# send = bot.div("Api_GetFriendList", {"c1": 3414744631})
+# print(type(send))
+# send2 = tool.python_to_json(content=send)
+# print(send2)
+# print(type(send2))
